"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initEventsCollector = void 0;
var _playEvent = require("./events/play-event");
var _pauseEvent = require("./events/pause-event");
var _metadataEvent = require("./events/metadata-event");
var _events = require("./utils/events");
const initEventsCollector = playerAdapter => {
  const collectedEvents = {};
  const rawEvents = {};
  return () => {
    let viewId = null;
    const registeredEvents = [];
    const start = _viewId => {
      if (viewId) {
        throw new Error('Events collector session already started');
      }
      // create new collection of events for new video view
      viewId = _viewId;
      collectedEvents[viewId] = [];
      rawEvents[viewId] = [];
      registeredEvents.push((0, _playEvent.registerPlayEvent)(playerAdapter, reportEvent), (0, _pauseEvent.registerPauseEvent)(playerAdapter, reportEvent), (0, _metadataEvent.registerMetadataEvent)(playerAdapter, reportEvent));
    };
    const destroy = () => {
      if (!viewId) {
        throw new Error('Events collector session not started');
      }
      registeredEvents.forEach(cb => cb());
      viewId = null;
    };
    const reportEvent = (eventName, eventDetails) => {
      if (!viewId) {
        throw new Error('Events collector session not started');
      }
      rawEvents[viewId].push((0, _events.createEvent)(eventName, eventDetails));
    };
    const flushEvents = () => {
      if (!viewId) {
        throw new Error('Events collector session not started');
      }
      const events = rawEvents[viewId].splice(0, rawEvents[viewId].length);
      collectedEvents[viewId].splice(collectedEvents[viewId].length, 0, ...events);
      return events;
    };
    const getCollectedEventsCount = () => {
      if (viewId) {
        var _rawEvents$viewId;
        return ((_rawEvents$viewId = rawEvents[viewId]) === null || _rawEvents$viewId === void 0 ? void 0 : _rawEvents$viewId.length) || 0;
      }
      return 0;
    };
    return {
      flushEvents,
      getCollectedEventsCount,
      addEvent: ({
        eventName,
        eventDetails
      }) => reportEvent(eventName, eventDetails),
      start,
      destroy
    };
  };
};
exports.initEventsCollector = initEventsCollector;
//# sourceMappingURL=events-collector.js.map