"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.registerMetadataEvent = exports.parseVideoDuration = void 0;
var _events = require("../events.consts");
const parseVideoDuration = durationValue => {
  const videoDuration = Number.isNaN(durationValue) ? null : durationValue;
  return Number.POSITIVE_INFINITY === videoDuration ? 'Infinity' : videoDuration;
};
exports.parseVideoDuration = parseVideoDuration;
const registerMetadataEvent = (playerAdapter, reportEvent) => {
  const reportLoadedMetadata = () => {
    reportEvent(_events.VIDEO_EVENT.LOADED_METADATA, {
      videoDuration: parseVideoDuration(playerAdapter.getDuration()),
      videoUrl: playerAdapter.getCurrentSrc()
    });
  };
  const eventLoadedMetadataClearCallback = playerAdapter.onLoadedMetadata(() => reportLoadedMetadata());
  if (playerAdapter.getReadyState() > 0) {
    // make it async to allow collect any initial events
    setTimeout(() => reportLoadedMetadata(), 0);
  }
  return () => {
    eventLoadedMetadataClearCallback();
  };
};
exports.registerMetadataEvent = registerMetadataEvent;
//# sourceMappingURL=metadata-event.js.map